==> jc-1.4.0.tar.gz: gnu/java/security/Engine.h <==
// public final class gnu.java.security.Engine

// class file dependencies
// @dep_class f4ba095546954b36 gnu_java_security_Engine
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_security_Engine_H_
#define _JC_gnu_java_security_Engine_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_lang_reflect_Constructor$object;
struct _jc_java_security_Provider$object;

// Typedefs
typedef struct _jc_gnu_java_security_Engine$sub_refs	_jc_gnu_java_security_Engine$sub_refs;
typedef struct _jc_gnu_java_security_Engine$sub_nonrefs	_jc_gnu_java_security_Engine$sub_nonrefs;
typedef struct _jc_gnu_java_security_Engine$refs	_jc_gnu_java_security_Engine$refs;
typedef struct _jc_gnu_java_security_Engine$nonrefs	_jc_gnu_java_security_Engine$nonrefs;
typedef struct _jc_gnu_java_security_Engine$object	_jc_gnu_java_security_Engine$object;

typedef struct _jc_gnu_java_security_Engine$fields_struct	_jc_gnu_java_security_Engine$fields_struct;
typedef const struct _jc_gnu_java_security_Engine$vmethods	_jc_gnu_java_security_Engine$vmethods;
typedef const struct _jc_gnu_java_security_Engine$vtable	_jc_gnu_java_security_Engine$vtable;
typedef const struct _jc_gnu_java_security_Engine$vtype	_jc_gnu_java_security_Engine$vtype;

// Class fields structure
struct _jc_gnu_java_security_Engine$fields_struct {
	struct _jc_java_lang_String$object	*ALG__5fALIAS;
	_jc_object_array	*NO__5fARGS;
	jint	MAX__5fALIASES;
};
extern _jc_gnu_java_security_Engine$fields_struct _jc_gnu_java_security_Engine$class_fields;

// Constructors
extern void _jc_gnu_java_security_Engine$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_security_Engine$object *);

// Static methods
extern void _jc_gnu_java_security_Engine$method$_clinit$a816641e0ba8bfef(_jc_env *);
extern struct _jc_java_lang_reflect_Constructor$object *_jc_gnu_java_security_Engine$method$getCompatibleConstructor$5e71a997446c7915(_jc_env *, struct _jc_java_lang_Class$object *, struct _jc_object_array *);
extern struct _jc_java_lang_Object$object *_jc_gnu_java_security_Engine$method$getInstance$ecf9c70a70f86177(_jc_env *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *, struct _jc_java_security_Provider$object *);
extern struct _jc_java_lang_Object$object *_jc_gnu_java_security_Engine$method$getInstance$ec89dfd35c234c64(_jc_env *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *, struct _jc_java_security_Provider$object *, struct _jc_object_array *);

// Virtual methods structure
struct _jc_gnu_java_security_Engine$vmethods {
};

// Vtable
struct _jc_gnu_java_security_Engine$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_security_Engine$vmethods	gnu_java_security_Engine;
};

// Vtype
struct _jc_gnu_java_security_Engine$vtype {
	_jc_type			type;
	_jc_gnu_java_security_Engine$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_security_Engine$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_security_Engine$refs {
    _jc_gnu_java_security_Engine$sub_refs	gnu_java_security_Engine;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_security_Engine$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_security_Engine$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_security_Engine$sub_nonrefs	gnu_java_security_Engine;
};

// Object instance structure
struct _jc_gnu_java_security_Engine$object {
	_jc_gnu_java_security_Engine$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_security_Engine$vtype	*vtype;
	_jc_gnu_java_security_Engine$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_security_Engine$vtype _jc_gnu_java_security_Engine$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_security_Engine, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_security_Engine$class_object;

#endif	/* _JC_gnu_java_security_Engine_H_ */

==> jc-1.4.6.tar.gz: gnu/java/security/Engine.h <==
// public final class gnu.java.security.Engine

// class file dependencies
// @dep_class f4ba095546954b36 gnu_java_security_Engine
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_security_Engine_H_
#define _JC_gnu_java_security_Engine_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_lang_reflect_Constructor$object;
struct _jc_java_security_Provider$object;

// Typedefs
typedef struct _jc_gnu_java_security_Engine$sub_refs	_jc_gnu_java_security_Engine$sub_refs;
typedef struct _jc_gnu_java_security_Engine$sub_nonrefs	_jc_gnu_java_security_Engine$sub_nonrefs;
typedef struct _jc_gnu_java_security_Engine$refs	_jc_gnu_java_security_Engine$refs;
typedef struct _jc_gnu_java_security_Engine$nonrefs	_jc_gnu_java_security_Engine$nonrefs;
typedef struct _jc_gnu_java_security_Engine$object	_jc_gnu_java_security_Engine$object;

typedef struct _jc_gnu_java_security_Engine$fields_struct	_jc_gnu_java_security_Engine$fields_struct;
typedef const struct _jc_gnu_java_security_Engine$vmethods	_jc_gnu_java_security_Engine$vmethods;
typedef const struct _jc_gnu_java_security_Engine$vtable	_jc_gnu_java_security_Engine$vtable;
typedef const struct _jc_gnu_java_security_Engine$vtype	_jc_gnu_java_security_Engine$vtype;

// Class fields structure
struct _jc_gnu_java_security_Engine$fields_struct {
	struct _jc_java_lang_String$object	*ALG__5fALIAS;
	_jc_object_array	*NO__5fARGS;
	jint	MAX__5fALIASES;
};
extern _jc_gnu_java_security_Engine$fields_struct _jc_gnu_java_security_Engine$class_fields;

// Constructors
extern void _jc_gnu_java_security_Engine$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_security_Engine$object *) _JC_JCNI_ATTR;

// Static methods
extern void _jc_gnu_java_security_Engine$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_reflect_Constructor$object *_jc_gnu_java_security_Engine$method$getCompatibleConstructor$5e71a997446c7915(_jc_env *, struct _jc_java_lang_Class$object *, struct _jc_object_array *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_gnu_java_security_Engine$method$getInstance$ecf9c70a70f86177(_jc_env *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *, struct _jc_java_security_Provider$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_gnu_java_security_Engine$method$getInstance$ec89dfd35c234c64(_jc_env *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *, struct _jc_java_security_Provider$object *, struct _jc_object_array *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_gnu_java_security_Engine$vmethods {
};

// Vtable
struct _jc_gnu_java_security_Engine$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_security_Engine$vmethods	gnu_java_security_Engine;
};

// Vtype
struct _jc_gnu_java_security_Engine$vtype {
	_jc_type			type;
	_jc_gnu_java_security_Engine$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_security_Engine$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_security_Engine$refs {
    _jc_gnu_java_security_Engine$sub_refs	gnu_java_security_Engine;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_security_Engine$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_security_Engine$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_security_Engine$sub_nonrefs	gnu_java_security_Engine;
};

// Object instance structure
struct _jc_gnu_java_security_Engine$object {
	_jc_gnu_java_security_Engine$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_security_Engine$vtype	*vtype;
	_jc_gnu_java_security_Engine$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_security_Engine$vtype _jc_gnu_java_security_Engine$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_security_Engine, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_security_Engine$class_object;

#endif	/* _JC_gnu_java_security_Engine_H_ */
